==> haskell-gitrev-1.3.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gitrev
version:              1.3.1
visibility:           public
id:                   gitrev-1.3.1-1rbGTqrAtYS9ErCWqXvHZK
key:                  gitrev-1.3.1-1rbGTqrAtYS9ErCWqXvHZK
license:              BSD-3-Clause
maintainer:           acfoltzer@galois.com
author:               Adam C. Foltzer
homepage:             https://github.com/acfoltzer/gitrev
synopsis:             Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.

category:             Development
abi:                  9d1ddd16ef911a53f339bccb163d2fd8
exposed:              True
exposed-modules:      Development.GitRev
import-dirs:          /usr/lib/ghc-9.0.2/site-local/gitrev-1.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gitrev
hs-libraries:         HSgitrev-1.3.1-1rbGTqrAtYS9ErCWqXvHZK
depends:
    base-4.15.1.0 base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    directory-1.3.6.2 filepath-1.4.2.1 process-1.6.13.2
    template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html:         /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gitrev-1.3.1-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gitrev
version:              1.3.1
visibility:           public
id:                   gitrev-1.3.1-9lQGgHpaqCODNpyMdeEqev
key:                  gitrev-1.3.1-9lQGgHpaqCODNpyMdeEqev
license:              BSD-3-Clause
maintainer:           acfoltzer@galois.com
author:               Adam C. Foltzer
homepage:             https://github.com/acfoltzer/gitrev
synopsis:             Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.

category:             Development
abi:                  71101ecb7294d7eb56ba6d96870a85e6
exposed:              True
exposed-modules:      Development.GitRev
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gitrev-1.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gitrev
hs-libraries:         HSgitrev-1.3.1-9lQGgHpaqCODNpyMdeEqev
depends:
    base-4.16.4.0 base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    directory-1.3.6.2 filepath-1.4.2.2 process-1.6.16.0
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html:         /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
